==> org-lsst-sal-atcamera-2.2.0-sources.jar: org/lsst/sal/atcamera/event/FocalPlaneSummaryInfoEvent.java <==
package org.lsst.sal.atcamera.event;

import org.lsst.sal.SALEnum;
import org.lsst.sal.camera.CameraEvent;

public class FocalPlaneSummaryInfoEvent extends CameraEvent {
  private final String ccdLocation;

  private final String raftBay;

  private final String ccdSlot;

  private final String rebSerialNumber;

  private final String rebLSSTName;

  private final String ccdLSSTName;

  private final String raftLSSTName;

  private final String ccdManSerNum;

  private final String ccdManufacturer;

  private final CcdType ccdType;

  private final double ccdTempSetPoint;

  private final String sequencerKey;

  private final String sequencerChecksum;

  public FocalPlaneSummaryInfoEvent(int priority, String ccdLocation, String raftBay,
      String ccdSlot, String rebSerialNumber, String rebLSSTName, String ccdLSSTName,
      String raftLSSTName, String ccdManSerNum, String ccdManufacturer, CcdType ccdType,
      double ccdTempSetPoint, String sequencerKey, String sequencerChecksum) {
    super (priority);
    this.ccdLocation = ccdLocation;
    this.raftBay = raftBay;
    this.ccdSlot = ccdSlot;
    this.rebSerialNumber = rebSerialNumber;
    this.rebLSSTName = rebLSSTName;
    this.ccdLSSTName = ccdLSSTName;
    this.raftLSSTName = raftLSSTName;
    this.ccdManSerNum = ccdManSerNum;
    this.ccdManufacturer = ccdManufacturer;
    this.ccdType = ccdType;
    this.ccdTempSetPoint = ccdTempSetPoint;
    this.sequencerKey = sequencerKey;
    this.sequencerChecksum = sequencerChecksum;
  }

  public String getCcdLocation() {
    return ccdLocation;
  }

  public String getRaftBay() {
    return raftBay;
  }

  public String getCcdSlot() {
    return ccdSlot;
  }

  public String getRebSerialNumber() {
    return rebSerialNumber;
  }

  public String getRebLSSTName() {
    return rebLSSTName;
  }

  public String getCcdLSSTName() {
    return ccdLSSTName;
  }

  public String getRaftLSSTName() {
    return raftLSSTName;
  }

  public String getCcdManSerNum() {
    return ccdManSerNum;
  }

  public String getCcdManufacturer() {
    return ccdManufacturer;
  }

  public CcdType getCcdType() {
    return ccdType;
  }

  public double getCcdTempSetPoint() {
    return ccdTempSetPoint;
  }

  public String getSequencerKey() {
    return sequencerKey;
  }

  public String getSequencerChecksum() {
    return sequencerChecksum;
  }

  @Override
  public String toString() {
    return "FocalPlaneSummaryInfoEvent{" + "ccdLocation=" + ccdLocation +", raftBay=" + raftBay +
        ", ccdSlot=" + ccdSlot +", rebSerialNumber=" + rebSerialNumber +
        ", rebLSSTName=" + rebLSSTName +", ccdLSSTName=" + ccdLSSTName +
        ", raftLSSTName=" + raftLSSTName +", ccdManSerNum=" + ccdManSerNum +
        ", ccdManufacturer=" + ccdManufacturer +", ccdType=" + ccdType +
        ", ccdTempSetPoint=" + ccdTempSetPoint +", sequencerKey=" + sequencerKey +
        ", sequencerChecksum=" + sequencerChecksum +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public enum CcdType implements SALEnum {
    E2V,

    ITL
  }

  public static class Builder {
    private int priority;

    private String ccdLocation;

    private String raftBay;

    private String ccdSlot;

    private String rebSerialNumber;

    private String rebLSSTName;

    private String ccdLSSTName;

    private String raftLSSTName;

    private String ccdManSerNum;

    private String ccdManufacturer;

    private CcdType ccdType;

    private double ccdTempSetPoint;

    private String sequencerKey;

    private String sequencerChecksum;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder ccdLocation(String ccdLocation) {
      this.ccdLocation = ccdLocation;
      return this;
    }

    public Builder raftBay(String raftBay) {
      this.raftBay = raftBay;
      return this;
    }

    public Builder ccdSlot(String ccdSlot) {
      this.ccdSlot = ccdSlot;
      return this;
    }

    public Builder rebSerialNumber(String rebSerialNumber) {
      this.rebSerialNumber = rebSerialNumber;
      return this;
    }

    public Builder rebLSSTName(String rebLSSTName) {
      this.rebLSSTName = rebLSSTName;
      return this;
    }

    public Builder ccdLSSTName(String ccdLSSTName) {
      this.ccdLSSTName = ccdLSSTName;
      return this;
    }

    public Builder raftLSSTName(String raftLSSTName) {
      this.raftLSSTName = raftLSSTName;
      return this;
    }

    public Builder ccdManSerNum(String ccdManSerNum) {
      this.ccdManSerNum = ccdManSerNum;
      return this;
    }

    public Builder ccdManufacturer(String ccdManufacturer) {
      this.ccdManufacturer = ccdManufacturer;
      return this;
    }

    public Builder ccdType(CcdType ccdType) {
      this.ccdType = ccdType;
      return this;
    }

    public Builder ccdTempSetPoint(double ccdTempSetPoint) {
      this.ccdTempSetPoint = ccdTempSetPoint;
      return this;
    }

    public Builder sequencerKey(String sequencerKey) {
      this.sequencerKey = sequencerKey;
      return this;
    }

    public Builder sequencerChecksum(String sequencerChecksum) {
      this.sequencerChecksum = sequencerChecksum;
      return this;
    }

    public FocalPlaneSummaryInfoEvent build() {
      return new FocalPlaneSummaryInfoEvent(priority, ccdLocation, raftBay, ccdSlot, rebSerialNumber, rebLSSTName, ccdLSSTName, raftLSSTName, ccdManSerNum, ccdManufacturer, ccdType, ccdTempSetPoint, sequencerKey, sequencerChecksum);
    }
  }
}

==> org-lsst-sal-atcamera-2.5.9-sources.jar: org/lsst/sal/atcamera/event/FocalPlaneSummaryInfoEvent.java <==
package org.lsst.sal.atcamera.event;

import org.lsst.sal.SALEnum;
import org.lsst.sal.camera.CameraEvent;

public class FocalPlaneSummaryInfoEvent extends CameraEvent {
  private final String ccdLocation;

  private final String raftBay;

  private final String ccdSlot;

  private final String rebSerialNumber;

  private final String rebLSSTName;

  private final String ccdLSSTName;

  private final String raftLSSTName;

  private final String ccdManSerNum;

  private final String ccdManufacturer;

  private final CcdType ccdType;

  private final double ccdTempSetPoint;

  private final String sequencerKey;

  private final String sequencerChecksum;

  public FocalPlaneSummaryInfoEvent(String ccdLocation, String raftBay, String ccdSlot,
      String rebSerialNumber, String rebLSSTName, String ccdLSSTName, String raftLSSTName,
      String ccdManSerNum, String ccdManufacturer, CcdType ccdType, double ccdTempSetPoint,
      String sequencerKey, String sequencerChecksum) {
    this.ccdLocation = ccdLocation;
    this.raftBay = raftBay;
    this.ccdSlot = ccdSlot;
    this.rebSerialNumber = rebSerialNumber;
    this.rebLSSTName = rebLSSTName;
    this.ccdLSSTName = ccdLSSTName;
    this.raftLSSTName = raftLSSTName;
    this.ccdManSerNum = ccdManSerNum;
    this.ccdManufacturer = ccdManufacturer;
    this.ccdType = ccdType;
    this.ccdTempSetPoint = ccdTempSetPoint;
    this.sequencerKey = sequencerKey;
    this.sequencerChecksum = sequencerChecksum;
  }

  public String getCcdLocation() {
    return ccdLocation;
  }

  public String getRaftBay() {
    return raftBay;
  }

  public String getCcdSlot() {
    return ccdSlot;
  }

  public String getRebSerialNumber() {
    return rebSerialNumber;
  }

  public String getRebLSSTName() {
    return rebLSSTName;
  }

  public String getCcdLSSTName() {
    return ccdLSSTName;
  }

  public String getRaftLSSTName() {
    return raftLSSTName;
  }

  public String getCcdManSerNum() {
    return ccdManSerNum;
  }

  public String getCcdManufacturer() {
    return ccdManufacturer;
  }

  public CcdType getCcdType() {
    return ccdType;
  }

  public double getCcdTempSetPoint() {
    return ccdTempSetPoint;
  }

  public String getSequencerKey() {
    return sequencerKey;
  }

  public String getSequencerChecksum() {
    return sequencerChecksum;
  }

  @Override
  public String toString() {
    return "FocalPlaneSummaryInfoEvent{" + "ccdLocation=" + ccdLocation +", raftBay=" + raftBay +
        ", ccdSlot=" + ccdSlot +", rebSerialNumber=" + rebSerialNumber +
        ", rebLSSTName=" + rebLSSTName +", ccdLSSTName=" + ccdLSSTName +
        ", raftLSSTName=" + raftLSSTName +", ccdManSerNum=" + ccdManSerNum +
        ", ccdManufacturer=" + ccdManufacturer +", ccdType=" + ccdType +
        ", ccdTempSetPoint=" + ccdTempSetPoint +", sequencerKey=" + sequencerKey +
        ", sequencerChecksum=" + sequencerChecksum +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public enum CcdType implements SALEnum {
    E2V,

    ITL
  }

  public static class Builder {
    private String ccdLocation;

    private String raftBay;

    private String ccdSlot;

    private String rebSerialNumber;

    private String rebLSSTName;

    private String ccdLSSTName;

    private String raftLSSTName;

    private String ccdManSerNum;

    private String ccdManufacturer;

    private CcdType ccdType;

    private double ccdTempSetPoint;

    private String sequencerKey;

    private String sequencerChecksum;

    private Builder() {
    }

    public Builder ccdLocation(String ccdLocation) {
      this.ccdLocation = ccdLocation;
      return this;
    }

    public Builder raftBay(String raftBay) {
      this.raftBay = raftBay;
      return this;
    }

    public Builder ccdSlot(String ccdSlot) {
      this.ccdSlot = ccdSlot;
      return this;
    }

    public Builder rebSerialNumber(String rebSerialNumber) {
      this.rebSerialNumber = rebSerialNumber;
      return this;
    }

    public Builder rebLSSTName(String rebLSSTName) {
      this.rebLSSTName = rebLSSTName;
      return this;
    }

    public Builder ccdLSSTName(String ccdLSSTName) {
      this.ccdLSSTName = ccdLSSTName;
      return this;
    }

    public Builder raftLSSTName(String raftLSSTName) {
      this.raftLSSTName = raftLSSTName;
      return this;
    }

    public Builder ccdManSerNum(String ccdManSerNum) {
      this.ccdManSerNum = ccdManSerNum;
      return this;
    }

    public Builder ccdManufacturer(String ccdManufacturer) {
      this.ccdManufacturer = ccdManufacturer;
      return this;
    }

    public Builder ccdType(CcdType ccdType) {
      this.ccdType = ccdType;
      return this;
    }

    public Builder ccdTempSetPoint(double ccdTempSetPoint) {
      this.ccdTempSetPoint = ccdTempSetPoint;
      return this;
    }

    public Builder sequencerKey(String sequencerKey) {
      this.sequencerKey = sequencerKey;
      return this;
    }

    public Builder sequencerChecksum(String sequencerChecksum) {
      this.sequencerChecksum = sequencerChecksum;
      return this;
    }

    public FocalPlaneSummaryInfoEvent build() {
      return new FocalPlaneSummaryInfoEvent(ccdLocation, raftBay, ccdSlot, rebSerialNumber, rebLSSTName, ccdLSSTName, raftLSSTName, ccdManSerNum, ccdManufacturer, ccdType, ccdTempSetPoint, sequencerKey, sequencerChecksum);
    }
  }
}
